/* selectionbar.c generated by valac 0.22.0.39-4730, the Vala compiler
 * generated from selectionbar.vala, do not modify */

/* This file is part of GNOME Boxes. License: LGPLv2+*/

#include <glib.h>
#include <glib-object.h>
#include <gtk/gtk.h>
#include <clutter/clutter.h>
#include <gio/gio.h>
#include <gdk-pixbuf/gdk-pixbuf.h>
#include <libcommon.h>
#include <glib/gi18n-lib.h>
#include <clutter-gtk/clutter-gtk.h>
#include <stdlib.h>
#include <string.h>
#include <libgd/gd.h>


#define BOXES_TYPE_SELECTIONBAR (boxes_selectionbar_get_type ())
#define BOXES_SELECTIONBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_SELECTIONBAR, BoxesSelectionbar))
#define BOXES_SELECTIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_SELECTIONBAR, BoxesSelectionbarClass))
#define BOXES_IS_SELECTIONBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_SELECTIONBAR))
#define BOXES_IS_SELECTIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_SELECTIONBAR))
#define BOXES_SELECTIONBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_SELECTIONBAR, BoxesSelectionbarClass))

typedef struct _BoxesSelectionbar BoxesSelectionbar;
typedef struct _BoxesSelectionbarClass BoxesSelectionbarClass;
typedef struct _BoxesSelectionbarPrivate BoxesSelectionbarPrivate;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))

#define BOXES_TYPE_UI (boxes_ui_get_type ())
#define BOXES_UI(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_UI, BoxesUI))
#define BOXES_UI_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_UI, BoxesUIClass))
#define BOXES_IS_UI(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_UI))
#define BOXES_IS_UI_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_UI))
#define BOXES_UI_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_UI, BoxesUIClass))

typedef struct _BoxesUI BoxesUI;
typedef struct _BoxesUIClass BoxesUIClass;

#define BOXES_TYPE_APP (boxes_app_get_type ())
#define BOXES_APP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_APP, BoxesApp))
#define BOXES_APP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_APP, BoxesAppClass))
#define BOXES_IS_APP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_APP))
#define BOXES_IS_APP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_APP))
#define BOXES_APP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_APP, BoxesAppClass))

typedef struct _BoxesApp BoxesApp;
typedef struct _BoxesAppClass BoxesAppClass;

#define BOXES_TYPE_COLLECTION_ITEM (boxes_collection_item_get_type ())
#define BOXES_COLLECTION_ITEM(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItem))
#define BOXES_COLLECTION_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItemClass))
#define BOXES_IS_COLLECTION_ITEM(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION_ITEM))
#define BOXES_IS_COLLECTION_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION_ITEM))
#define BOXES_COLLECTION_ITEM_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItemClass))

typedef struct _BoxesCollectionItem BoxesCollectionItem;
typedef struct _BoxesCollectionItemClass BoxesCollectionItemClass;

#define BOXES_TYPE_MACHINE (boxes_machine_get_type ())
#define BOXES_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_MACHINE, BoxesMachine))
#define BOXES_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_MACHINE, BoxesMachineClass))
#define BOXES_IS_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_MACHINE))
#define BOXES_IS_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_MACHINE))
#define BOXES_MACHINE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_MACHINE, BoxesMachineClass))

typedef struct _BoxesMachine BoxesMachine;
typedef struct _BoxesMachineClass BoxesMachineClass;
typedef struct _BoxesUIPrivate BoxesUIPrivate;
typedef struct _BoxesCollectionItemPrivate BoxesCollectionItemPrivate;

#define BOXES_TYPE_IPROPERTIES_PROVIDER (boxes_iproperties_provider_get_type ())
#define BOXES_IPROPERTIES_PROVIDER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_IPROPERTIES_PROVIDER, BoxesIPropertiesProvider))
#define BOXES_IS_IPROPERTIES_PROVIDER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_IPROPERTIES_PROVIDER))
#define BOXES_IPROPERTIES_PROVIDER_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), BOXES_TYPE_IPROPERTIES_PROVIDER, BoxesIPropertiesProviderIface))

typedef struct _BoxesIPropertiesProvider BoxesIPropertiesProvider;
typedef struct _BoxesIPropertiesProviderIface BoxesIPropertiesProviderIface;

#define BOXES_TYPE_PROPERTIES_PAGE (boxes_properties_page_get_type ())

#define TYPE_PROPERTY_CREATION_FLAG (property_creation_flag_get_type ())

#define BOXES_TYPE_PROPERTY (boxes_property_get_type ())
#define BOXES_PROPERTY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_PROPERTY, BoxesProperty))
#define BOXES_PROPERTY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_PROPERTY, BoxesPropertyClass))
#define BOXES_IS_PROPERTY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_PROPERTY))
#define BOXES_IS_PROPERTY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_PROPERTY))
#define BOXES_PROPERTY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_PROPERTY, BoxesPropertyClass))

typedef struct _BoxesProperty BoxesProperty;
typedef struct _BoxesPropertyClass BoxesPropertyClass;
typedef struct _BoxesMachinePrivate BoxesMachinePrivate;

#define BOXES_MACHINE_TYPE_CONNECT_FLAGS (boxes_machine_connect_flags_get_type ())
#define __g_list_free__g_object_unref0_0(var) ((var == NULL) ? NULL : (var = (_g_list_free__g_object_unref0_ (var), NULL)))
typedef struct _Block54Data Block54Data;
typedef struct _BoxesAppPrivate BoxesAppPrivate;

#define BOXES_TYPE_CLUTTER_WIDGET (boxes_clutter_widget_get_type ())
#define BOXES_CLUTTER_WIDGET(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_CLUTTER_WIDGET, BoxesClutterWidget))
#define BOXES_CLUTTER_WIDGET_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_CLUTTER_WIDGET, BoxesClutterWidgetClass))
#define BOXES_IS_CLUTTER_WIDGET(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_CLUTTER_WIDGET))
#define BOXES_IS_CLUTTER_WIDGET_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_CLUTTER_WIDGET))
#define BOXES_CLUTTER_WIDGET_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_CLUTTER_WIDGET, BoxesClutterWidgetClass))

typedef struct _BoxesClutterWidget BoxesClutterWidget;
typedef struct _BoxesClutterWidgetClass BoxesClutterWidgetClass;

#define BOXES_TYPE_SEARCHBAR (boxes_searchbar_get_type ())
#define BOXES_SEARCHBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_SEARCHBAR, BoxesSearchbar))
#define BOXES_SEARCHBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_SEARCHBAR, BoxesSearchbarClass))
#define BOXES_IS_SEARCHBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_SEARCHBAR))
#define BOXES_IS_SEARCHBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_SEARCHBAR))
#define BOXES_SEARCHBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_SEARCHBAR, BoxesSearchbarClass))

typedef struct _BoxesSearchbar BoxesSearchbar;
typedef struct _BoxesSearchbarClass BoxesSearchbarClass;

#define BOXES_TYPE_TOPBAR (boxes_topbar_get_type ())
#define BOXES_TOPBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_TOPBAR, BoxesTopbar))
#define BOXES_TOPBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_TOPBAR, BoxesTopbarClass))
#define BOXES_IS_TOPBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_TOPBAR))
#define BOXES_IS_TOPBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_TOPBAR))
#define BOXES_TOPBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_TOPBAR, BoxesTopbarClass))

typedef struct _BoxesTopbar BoxesTopbar;
typedef struct _BoxesTopbarClass BoxesTopbarClass;

#define BOXES_TYPE_NOTIFICATIONBAR (boxes_notificationbar_get_type ())
#define BOXES_NOTIFICATIONBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbar))
#define BOXES_NOTIFICATIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbarClass))
#define BOXES_IS_NOTIFICATIONBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_NOTIFICATIONBAR))
#define BOXES_IS_NOTIFICATIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_NOTIFICATIONBAR))
#define BOXES_NOTIFICATIONBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbarClass))

typedef struct _BoxesNotificationbar BoxesNotificationbar;
typedef struct _BoxesNotificationbarClass BoxesNotificationbarClass;

#define BOXES_TYPE_REVEALER (boxes_revealer_get_type ())
#define BOXES_REVEALER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_REVEALER, BoxesRevealer))
#define BOXES_REVEALER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_REVEALER, BoxesRevealerClass))
#define BOXES_IS_REVEALER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_REVEALER))
#define BOXES_IS_REVEALER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_REVEALER))
#define BOXES_REVEALER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_REVEALER, BoxesRevealerClass))

typedef struct _BoxesRevealer BoxesRevealer;
typedef struct _BoxesRevealerClass BoxesRevealerClass;

#define BOXES_TYPE_SIDEBAR (boxes_sidebar_get_type ())
#define BOXES_SIDEBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_SIDEBAR, BoxesSidebar))
#define BOXES_SIDEBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_SIDEBAR, BoxesSidebarClass))
#define BOXES_IS_SIDEBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_SIDEBAR))
#define BOXES_IS_SIDEBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_SIDEBAR))
#define BOXES_SIDEBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_SIDEBAR, BoxesSidebarClass))

typedef struct _BoxesSidebar BoxesSidebar;
typedef struct _BoxesSidebarClass BoxesSidebarClass;

#define BOXES_TYPE_WIZARD (boxes_wizard_get_type ())
#define BOXES_WIZARD(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_WIZARD, BoxesWizard))
#define BOXES_WIZARD_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_WIZARD, BoxesWizardClass))
#define BOXES_IS_WIZARD(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_WIZARD))
#define BOXES_IS_WIZARD_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_WIZARD))
#define BOXES_WIZARD_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_WIZARD, BoxesWizardClass))

typedef struct _BoxesWizard BoxesWizard;
typedef struct _BoxesWizardClass BoxesWizardClass;

#define BOXES_TYPE_PROPERTIES (boxes_properties_get_type ())
#define BOXES_PROPERTIES(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_PROPERTIES, BoxesProperties))
#define BOXES_PROPERTIES_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_PROPERTIES, BoxesPropertiesClass))
#define BOXES_IS_PROPERTIES(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_PROPERTIES))
#define BOXES_IS_PROPERTIES_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_PROPERTIES))
#define BOXES_PROPERTIES_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_PROPERTIES, BoxesPropertiesClass))

typedef struct _BoxesProperties BoxesProperties;
typedef struct _BoxesPropertiesClass BoxesPropertiesClass;

#define BOXES_TYPE_DISPLAY_PAGE (boxes_display_page_get_type ())
#define BOXES_DISPLAY_PAGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPage))
#define BOXES_DISPLAY_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPageClass))
#define BOXES_IS_DISPLAY_PAGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_DISPLAY_PAGE))
#define BOXES_IS_DISPLAY_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_DISPLAY_PAGE))
#define BOXES_DISPLAY_PAGE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPageClass))

typedef struct _BoxesDisplayPage BoxesDisplayPage;
typedef struct _BoxesDisplayPageClass BoxesDisplayPageClass;

#define BOXES_TYPE_EMPTY_BOXES (boxes_empty_boxes_get_type ())
#define BOXES_EMPTY_BOXES(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_EMPTY_BOXES, BoxesEmptyBoxes))
#define BOXES_EMPTY_BOXES_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_EMPTY_BOXES, BoxesEmptyBoxesClass))
#define BOXES_IS_EMPTY_BOXES(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_EMPTY_BOXES))
#define BOXES_IS_EMPTY_BOXES_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_EMPTY_BOXES))
#define BOXES_EMPTY_BOXES_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_EMPTY_BOXES, BoxesEmptyBoxesClass))

typedef struct _BoxesEmptyBoxes BoxesEmptyBoxes;
typedef struct _BoxesEmptyBoxesClass BoxesEmptyBoxesClass;

#define BOXES_TYPE_COLLECTION (boxes_collection_get_type ())
#define BOXES_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION, BoxesCollection))
#define BOXES_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION, BoxesCollectionClass))
#define BOXES_IS_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION))
#define BOXES_IS_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION))
#define BOXES_COLLECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION, BoxesCollectionClass))

typedef struct _BoxesCollection BoxesCollection;
typedef struct _BoxesCollectionClass BoxesCollectionClass;

#define BOXES_TYPE_COLLECTION_FILTER (boxes_collection_filter_get_type ())
#define BOXES_COLLECTION_FILTER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION_FILTER, BoxesCollectionFilter))
#define BOXES_COLLECTION_FILTER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION_FILTER, BoxesCollectionFilterClass))
#define BOXES_IS_COLLECTION_FILTER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION_FILTER))
#define BOXES_IS_COLLECTION_FILTER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION_FILTER))
#define BOXES_COLLECTION_FILTER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION_FILTER, BoxesCollectionFilterClass))

typedef struct _BoxesCollectionFilter BoxesCollectionFilter;
typedef struct _BoxesCollectionFilterClass BoxesCollectionFilterClass;

#define BOXES_TYPE_COLLECTION_VIEW (boxes_collection_view_get_type ())
#define BOXES_COLLECTION_VIEW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION_VIEW, BoxesCollectionView))
#define BOXES_COLLECTION_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION_VIEW, BoxesCollectionViewClass))
#define BOXES_IS_COLLECTION_VIEW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION_VIEW))
#define BOXES_IS_COLLECTION_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION_VIEW))
#define BOXES_COLLECTION_VIEW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION_VIEW, BoxesCollectionViewClass))

typedef struct _BoxesCollectionView BoxesCollectionView;
typedef struct _BoxesCollectionViewClass BoxesCollectionViewClass;
#define _g_free0(var) (var = (g_free (var), NULL))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))

#define BOXES_MACHINE_TYPE_MACHINE_STATE (boxes_machine_machine_state_get_type ())
typedef struct _BoxesCollectionPrivate BoxesCollectionPrivate;

struct _BoxesSelectionbar {
	GtkRevealer parent_instance;
	BoxesSelectionbarPrivate * priv;
};

struct _BoxesSelectionbarClass {
	GtkRevealerClass parent_class;
};

struct _BoxesSelectionbarPrivate {
	GtkHeaderBar* headerbar;
	GtkToggleButton* favorite_btn;
	GtkButton* pause_btn;
	GtkButton* remove_btn;
	GtkButton* properties_btn;
	gulong favorite_btn_clicked_handler;
};

struct _BoxesUI {
	GObject parent_instance;
	BoxesUIPrivate * priv;
};

struct _BoxesUIClass {
	GObjectClass parent_class;
	void (*ui_state_changed) (BoxesUI* self);
	ClutterActor* (*get_actor) (BoxesUI* self);
};

struct _BoxesCollectionItem {
	BoxesUI parent_instance;
	BoxesCollectionItemPrivate * priv;
};

struct _BoxesCollectionItemClass {
	BoxesUIClass parent_class;
	gint (*compare) (BoxesCollectionItem* self, BoxesCollectionItem* other);
};

typedef enum  {
	BOXES_PROPERTIES_PAGE_LOGIN,
	BOXES_PROPERTIES_PAGE_SYSTEM,
	BOXES_PROPERTIES_PAGE_DISPLAY,
	BOXES_PROPERTIES_PAGE_DEVICES,
	BOXES_PROPERTIES_PAGE_LAST
} BoxesPropertiesPage;

typedef enum  {
	PROPERTY_CREATION_FLAG_NONE = 1 << 0,
	PROPERTY_CREATION_FLAG_NO_USB = 1 << 1
} PropertyCreationFlag;

struct _BoxesIPropertiesProviderIface {
	GTypeInterface parent_iface;
	GList* (*get_properties) (BoxesIPropertiesProvider* self, BoxesPropertiesPage page, PropertyCreationFlag* flags);
};

typedef enum  {
	BOXES_MACHINE_CONNECT_FLAGS_NONE = 0,
	BOXES_MACHINE_CONNECT_FLAGS_IGNORE_SAVED_STATE = 1 << 0
} BoxesMachineConnectFlags;

struct _BoxesMachine {
	BoxesCollectionItem parent_instance;
	BoxesMachinePrivate * priv;
	BoxesCollectionSource* source;
	BoxesBoxConfig* config;
	gboolean stay_on_display;
	gboolean suspend_at_exit;
	gboolean deleted;
};

struct _BoxesMachineClass {
	BoxesCollectionItemClass parent_class;
	void (*save_real) (BoxesMachine* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*save_real_finish) (BoxesMachine* self, GAsyncResult* _res_, GError** error);
	void (*take_screenshot) (BoxesMachine* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
	GdkPixbuf* (*take_screenshot_finish) (BoxesMachine* self, GAsyncResult* _res_, GError** error);
	GList* (*get_properties) (BoxesMachine* self, BoxesPropertiesPage page, PropertyCreationFlag* flags);
	void (*connect_display) (BoxesMachine* self, BoxesMachineConnectFlags flags, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*connect_display_finish) (BoxesMachine* self, GAsyncResult* _res_, GError** error);
	void (*disconnect_display) (BoxesMachine* self);
	void (*delete) (BoxesMachine* self, gboolean by_user);
};

struct _Block54Data {
	int _ref_count_;
	BoxesSelectionbar * self;
	BoxesMachine* machine;
};

struct _BoxesApp {
	BoxesUI parent_instance;
	BoxesAppPrivate * priv;
	GtkApplicationWindow* window;
	GtkNotebook* notebook;
	BoxesClutterWidget* embed;
	ClutterStage* stage;
	ClutterBinLayout* stage_bin;
	ClutterActor* overlay_bin_actor;
	ClutterBinLayout* overlay_bin;
	BoxesCollectionItem* current_item;
	BoxesSearchbar* searchbar;
	BoxesTopbar* topbar;
	BoxesNotificationbar* notificationbar;
	BoxesRevealer* sidebar_revealer;
	BoxesRevealer* searchbar_revealer;
	BoxesSidebar* sidebar;
	BoxesSelectionbar* selectionbar;
	guint duration;
	GSettings* settings;
	BoxesWizard* wizard;
	BoxesProperties* properties;
	BoxesDisplayPage* display_page;
	BoxesEmptyBoxes* empty_boxes;
	BoxesCollection* collection;
	BoxesCollectionFilter* filter;
	BoxesCollectionView* view;
};

struct _BoxesAppClass {
	BoxesUIClass parent_class;
};

typedef enum  {
	BOXES_MACHINE_MACHINE_STATE_UNKNOWN,
	BOXES_MACHINE_MACHINE_STATE_STOPPED,
	BOXES_MACHINE_MACHINE_STATE_FORCE_STOPPED,
	BOXES_MACHINE_MACHINE_STATE_RUNNING,
	BOXES_MACHINE_MACHINE_STATE_PAUSED,
	BOXES_MACHINE_MACHINE_STATE_SAVED,
	BOXES_MACHINE_MACHINE_STATE_SLEEPING
} BoxesMachineMachineState;

struct _BoxesCollection {
	GObject parent_instance;
	BoxesCollectionPrivate * priv;
	GPtrArray* items;
};

struct _BoxesCollectionClass {
	GObjectClass parent_class;
};


static gpointer boxes_selectionbar_parent_class = NULL;
extern BoxesApp* boxes_app_app;

GType boxes_selectionbar_get_type (void) G_GNUC_CONST;
#define BOXES_SELECTIONBAR_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), BOXES_TYPE_SELECTIONBAR, BoxesSelectionbarPrivate))
enum  {
	BOXES_SELECTIONBAR_DUMMY_PROPERTY
};
BoxesSelectionbar* boxes_selectionbar_new (void);
BoxesSelectionbar* boxes_selectionbar_construct (GType object_type);
static void __lambda171_ (BoxesSelectionbar* self);
GType boxes_ui_get_type (void) G_GNUC_CONST;
GType boxes_app_get_type (void) G_GNUC_CONST;
GType boxes_collection_item_get_type (void) G_GNUC_CONST;
GList* boxes_app_get_selected_items (BoxesApp* self);
GType boxes_machine_get_type (void) G_GNUC_CONST;
GType boxes_properties_page_get_type (void) G_GNUC_CONST;
GType property_creation_flag_get_type (void) G_GNUC_CONST;
GType boxes_property_get_type (void) G_GNUC_CONST;
GType boxes_iproperties_provider_get_type (void) G_GNUC_CONST;
GType boxes_machine_connect_flags_get_type (void) G_GNUC_CONST;
static void _g_object_unref0_ (gpointer var);
static void _g_list_free__g_object_unref0_ (GList* self);
void boxes_app_set_selection_mode (BoxesApp* self, gboolean value);
static void ___lambda171__gtk_button_clicked (GtkButton* _sender, gpointer self);
static void __lambda172_ (BoxesSelectionbar* self);
static Block54Data* block54_data_ref (Block54Data* _data54_);
static void block54_data_unref (void * _userdata_);
void boxes_machine_save (BoxesMachine* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
void boxes_machine_save_finish (BoxesMachine* self, GAsyncResult* _res_, GError** error);
static void ____lambda173_ (Block54Data* _data54_, GObject* obj, GAsyncResult* _result_);
GType boxes_clutter_widget_get_type (void) G_GNUC_CONST;
GType boxes_searchbar_get_type (void) G_GNUC_CONST;
GType boxes_topbar_get_type (void) G_GNUC_CONST;
GType boxes_notificationbar_get_type (void) G_GNUC_CONST;
GType boxes_revealer_get_type (void) G_GNUC_CONST;
GType boxes_sidebar_get_type (void) G_GNUC_CONST;
GType boxes_wizard_get_type (void) G_GNUC_CONST;
GType boxes_properties_get_type (void) G_GNUC_CONST;
GType boxes_display_page_get_type (void) G_GNUC_CONST;
GType boxes_empty_boxes_get_type (void) G_GNUC_CONST;
GType boxes_collection_get_type (void) G_GNUC_CONST;
GType boxes_collection_filter_get_type (void) G_GNUC_CONST;
GType boxes_collection_view_get_type (void) G_GNUC_CONST;
GdNotification* boxes_notificationbar_display_error (BoxesNotificationbar* self, const gchar* message, gint timeout);
const gchar* boxes_collection_item_get_name (BoxesCollectionItem* self);
#define BOXES_NOTIFICATIONBAR_DEFAULT_TIMEOUT 6
static void _____lambda173__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self);
static void ___lambda172__gtk_button_clicked (GtkButton* _sender, gpointer self);
static void __lambda174_ (BoxesSelectionbar* self);
void boxes_app_remove_selected_items (BoxesApp* self);
static void ___lambda174__gtk_button_clicked (GtkButton* _sender, gpointer self);
static void __lambda177_ (BoxesSelectionbar* self);
void boxes_app_show_properties (BoxesApp* self);
static void ___lambda177__gtk_button_clicked (GtkButton* _sender, gpointer self);
static void __lambda178_ (BoxesSelectionbar* self);
gboolean boxes_app_get_selection_mode (BoxesApp* self);
static void ___lambda178__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static void __lambda179_ (BoxesSelectionbar* self);
static void boxes_selectionbar_update_favorite_btn (BoxesSelectionbar* self);
static void boxes_selectionbar_update_properties_btn (BoxesSelectionbar* self);
static void boxes_selectionbar_update_pause_btn (BoxesSelectionbar* self);
static void boxes_selectionbar_update_delete_btn (BoxesSelectionbar* self);
static void ___lambda179__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static gboolean _vala_string_array_contains (gchar** stack, int stack_length, gchar* needle);
gboolean boxes_machine_get_can_save (BoxesMachine* self);
GType boxes_machine_machine_state_get_type (void) G_GNUC_CONST;
BoxesMachineMachineState boxes_machine_get_state (BoxesMachine* self);
static void ____lambda180_ (BoxesSelectionbar* self);
static void _____lambda180__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
gboolean boxes_machine_get_can_delete (BoxesMachine* self);
static void boxes_selectionbar_finalize (GObject* obj);
static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func);
static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);


static gpointer _g_object_ref0 (gpointer self) {
#line 26 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	return self ? g_object_ref (self) : NULL;
#line 462 "selectionbar.c"
}


static void _g_object_unref0_ (gpointer var) {
#line 26 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	(var == NULL) ? NULL : (var = (g_object_unref (var), NULL));
#line 469 "selectionbar.c"
}


static void _g_list_free__g_object_unref0_ (GList* self) {
#line 26 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	g_list_foreach (self, (GFunc) _g_object_unref0_, NULL);
#line 26 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	g_list_free (self);
#line 478 "selectionbar.c"
}


static void __lambda171_ (BoxesSelectionbar* self) {
	BoxesApp* _tmp0_ = NULL;
	GList* _tmp1_ = NULL;
	GList* _tmp2_ = NULL;
	BoxesApp* _tmp12_ = NULL;
#line 26 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp0_ = boxes_app_app;
#line 26 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp1_ = boxes_app_get_selected_items (_tmp0_);
#line 26 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp2_ = _tmp1_;
#line 493 "selectionbar.c"
	{
		GList* item_collection = NULL;
		GList* item_it = NULL;
#line 26 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
		item_collection = _tmp2_;
#line 26 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
		for (item_it = item_collection; item_it != NULL; item_it = item_it->next) {
#line 501 "selectionbar.c"
			BoxesCollectionItem* _tmp3_ = NULL;
			BoxesCollectionItem* item = NULL;
#line 26 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
			_tmp3_ = _g_object_ref0 ((BoxesCollectionItem*) item_it->data);
#line 26 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
			item = _tmp3_;
#line 508 "selectionbar.c"
			{
				BoxesMachine* machine = NULL;
				BoxesCollectionItem* _tmp4_ = NULL;
				BoxesMachine* _tmp5_ = NULL;
				BoxesMachine* _tmp6_ = NULL;
				BoxesMachine* _tmp7_ = NULL;
				BoxesBoxConfig* _tmp8_ = NULL;
				GtkToggleButton* _tmp9_ = NULL;
				gboolean _tmp10_ = FALSE;
				gboolean _tmp11_ = FALSE;
#line 27 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				_tmp4_ = item;
#line 27 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				_tmp5_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp4_, BOXES_TYPE_MACHINE) ? ((BoxesMachine*) _tmp4_) : NULL);
#line 27 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				machine = _tmp5_;
#line 28 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				_tmp6_ = machine;
#line 28 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				if (_tmp6_ == NULL) {
#line 29 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
					_g_object_unref0 (machine);
#line 29 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
					_g_object_unref0 (item);
#line 29 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
					continue;
#line 535 "selectionbar.c"
				}
#line 30 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				_tmp7_ = machine;
#line 30 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				_tmp8_ = _tmp7_->config;
#line 30 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				_tmp9_ = self->priv->favorite_btn;
#line 30 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				_tmp10_ = gtk_toggle_button_get_active (_tmp9_);
#line 30 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				_tmp11_ = _tmp10_;
#line 30 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				boxes_box_config_set_category (_tmp8_, "favorite", _tmp11_);
#line 26 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				_g_object_unref0 (machine);
#line 26 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				_g_object_unref0 (item);
#line 553 "selectionbar.c"
			}
		}
#line 26 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
		__g_list_free__g_object_unref0_0 (item_collection);
#line 558 "selectionbar.c"
	}
#line 33 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp12_ = boxes_app_app;
#line 33 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	boxes_app_set_selection_mode (_tmp12_, FALSE);
#line 564 "selectionbar.c"
}


static void ___lambda171__gtk_button_clicked (GtkButton* _sender, gpointer self) {
#line 25 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	__lambda171_ (self);
#line 571 "selectionbar.c"
}


static Block54Data* block54_data_ref (Block54Data* _data54_) {
#line 41 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	g_atomic_int_inc (&_data54_->_ref_count_);
#line 41 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	return _data54_;
#line 580 "selectionbar.c"
}


static void block54_data_unref (void * _userdata_) {
	Block54Data* _data54_;
	_data54_ = (Block54Data*) _userdata_;
#line 41 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	if (g_atomic_int_dec_and_test (&_data54_->_ref_count_)) {
#line 589 "selectionbar.c"
		BoxesSelectionbar * self;
#line 41 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
		self = _data54_->self;
#line 41 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
		_g_object_unref0 (_data54_->machine);
#line 41 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
		_g_object_unref0 (self);
#line 41 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
		g_slice_free (Block54Data, _data54_);
#line 599 "selectionbar.c"
	}
}


static void ____lambda173_ (Block54Data* _data54_, GObject* obj, GAsyncResult* _result_) {
	BoxesSelectionbar * self;
	GError * _inner_error_ = NULL;
#line 45 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	self = _data54_->self;
#line 45 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	g_return_if_fail (_result_ != NULL);
#line 611 "selectionbar.c"
	{
		BoxesMachine* _tmp0_ = NULL;
		GAsyncResult* _tmp1_ = NULL;
#line 47 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
		_tmp0_ = _data54_->machine;
#line 47 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
		_tmp1_ = _result_;
#line 47 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
		boxes_machine_save_finish (_tmp0_, _tmp1_, &_inner_error_);
#line 47 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
		if (_inner_error_ != NULL) {
#line 623 "selectionbar.c"
			goto __catch66_g_error;
		}
	}
	goto __finally66;
	__catch66_g_error:
	{
		GError* e = NULL;
		BoxesApp* _tmp2_ = NULL;
		BoxesNotificationbar* _tmp3_ = NULL;
		const gchar* _tmp4_ = NULL;
		BoxesMachine* _tmp5_ = NULL;
		const gchar* _tmp6_ = NULL;
		const gchar* _tmp7_ = NULL;
		gchar* _tmp8_ = NULL;
		gchar* _tmp9_ = NULL;
		GdNotification* _tmp10_ = NULL;
		GdNotification* _tmp11_ = NULL;
#line 46 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
		e = _inner_error_;
#line 46 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
		_inner_error_ = NULL;
#line 49 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
		_tmp2_ = boxes_app_app;
#line 49 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
		_tmp3_ = _tmp2_->notificationbar;
#line 49 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
		_tmp4_ = _ ("Pausing '%s' failed");
#line 49 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
		_tmp5_ = _data54_->machine;
#line 49 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
		_tmp6_ = boxes_collection_item_get_name ((BoxesCollectionItem*) _tmp5_);
#line 49 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
		_tmp7_ = _tmp6_;
#line 49 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
		_tmp8_ = g_strdup_printf (_tmp4_, _tmp7_);
#line 49 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
		_tmp9_ = _tmp8_;
#line 49 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
		_tmp10_ = boxes_notificationbar_display_error (_tmp3_, _tmp9_, BOXES_NOTIFICATIONBAR_DEFAULT_TIMEOUT);
#line 49 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
		_tmp11_ = _tmp10_;
#line 49 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
		_g_object_unref0 (_tmp11_);
#line 49 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
		_g_free0 (_tmp9_);
#line 46 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
		_g_error_free0 (e);
#line 671 "selectionbar.c"
	}
	__finally66:
#line 46 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	if (_inner_error_ != NULL) {
#line 46 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 46 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
		g_clear_error (&_inner_error_);
#line 46 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
		return;
#line 682 "selectionbar.c"
	}
}


static void _____lambda173__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self) {
#line 45 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	____lambda173_ (self, source_object, res);
#line 45 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	block54_data_unref (self);
#line 692 "selectionbar.c"
}


static void __lambda172_ (BoxesSelectionbar* self) {
	BoxesApp* _tmp0_ = NULL;
	GList* _tmp1_ = NULL;
	GList* _tmp2_ = NULL;
	GtkButton* _tmp8_ = NULL;
	BoxesApp* _tmp9_ = NULL;
#line 41 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp0_ = boxes_app_app;
#line 41 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp1_ = boxes_app_get_selected_items (_tmp0_);
#line 41 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp2_ = _tmp1_;
#line 708 "selectionbar.c"
	{
		GList* item_collection = NULL;
		GList* item_it = NULL;
#line 41 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
		item_collection = _tmp2_;
#line 41 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
		for (item_it = item_collection; item_it != NULL; item_it = item_it->next) {
#line 716 "selectionbar.c"
			BoxesCollectionItem* _tmp3_ = NULL;
			BoxesCollectionItem* item = NULL;
#line 41 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
			_tmp3_ = _g_object_ref0 ((BoxesCollectionItem*) item_it->data);
#line 41 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
			item = _tmp3_;
#line 723 "selectionbar.c"
			{
				Block54Data* _data54_;
				BoxesCollectionItem* _tmp4_ = NULL;
				BoxesMachine* _tmp5_ = NULL;
				BoxesMachine* _tmp6_ = NULL;
				BoxesMachine* _tmp7_ = NULL;
#line 41 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				_data54_ = g_slice_new0 (Block54Data);
#line 41 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				_data54_->_ref_count_ = 1;
#line 41 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				_data54_->self = g_object_ref (self);
#line 42 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				_tmp4_ = item;
#line 42 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				_tmp5_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp4_, BOXES_TYPE_MACHINE) ? ((BoxesMachine*) _tmp4_) : NULL);
#line 42 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				_data54_->machine = _tmp5_;
#line 43 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				_tmp6_ = _data54_->machine;
#line 43 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				if (_tmp6_ == NULL) {
#line 44 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
					_g_object_unref0 (item);
#line 44 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
					block54_data_unref (_data54_);
#line 44 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
					_data54_ = NULL;
#line 44 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
					continue;
#line 754 "selectionbar.c"
				}
#line 45 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				_tmp7_ = _data54_->machine;
#line 45 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				boxes_machine_save (_tmp7_, _____lambda173__gasync_ready_callback, block54_data_ref (_data54_));
#line 41 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				_g_object_unref0 (item);
#line 41 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				block54_data_unref (_data54_);
#line 41 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				_data54_ = NULL;
#line 766 "selectionbar.c"
			}
		}
#line 41 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
		__g_list_free__g_object_unref0_0 (item_collection);
#line 771 "selectionbar.c"
	}
#line 54 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp8_ = self->priv->pause_btn;
#line 54 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	gtk_widget_set_sensitive ((GtkWidget*) _tmp8_, FALSE);
#line 55 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp9_ = boxes_app_app;
#line 55 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	boxes_app_set_selection_mode (_tmp9_, FALSE);
#line 781 "selectionbar.c"
}


static void ___lambda172__gtk_button_clicked (GtkButton* _sender, gpointer self) {
#line 40 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	__lambda172_ (self);
#line 788 "selectionbar.c"
}


static void __lambda174_ (BoxesSelectionbar* self) {
	BoxesApp* _tmp0_ = NULL;
#line 63 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp0_ = boxes_app_app;
#line 63 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	boxes_app_remove_selected_items (_tmp0_);
#line 798 "selectionbar.c"
}


static void ___lambda174__gtk_button_clicked (GtkButton* _sender, gpointer self) {
#line 62 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	__lambda174_ (self);
#line 805 "selectionbar.c"
}


static void __lambda177_ (BoxesSelectionbar* self) {
	BoxesApp* _tmp0_ = NULL;
#line 71 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp0_ = boxes_app_app;
#line 71 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	boxes_app_show_properties (_tmp0_);
#line 815 "selectionbar.c"
}


static void ___lambda177__gtk_button_clicked (GtkButton* _sender, gpointer self) {
#line 70 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	__lambda177_ (self);
#line 822 "selectionbar.c"
}


static void __lambda178_ (BoxesSelectionbar* self) {
	BoxesApp* _tmp0_ = NULL;
	gboolean _tmp1_ = FALSE;
	gboolean _tmp2_ = FALSE;
#line 77 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp0_ = boxes_app_app;
#line 77 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp1_ = boxes_app_get_selection_mode (_tmp0_);
#line 77 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp2_ = _tmp1_;
#line 77 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	gtk_revealer_set_reveal_child ((GtkRevealer*) self, _tmp2_);
#line 838 "selectionbar.c"
}


static void ___lambda178__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 76 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	__lambda178_ (self);
#line 845 "selectionbar.c"
}


static void __lambda179_ (BoxesSelectionbar* self) {
#line 81 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	boxes_selectionbar_update_favorite_btn (self);
#line 82 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	boxes_selectionbar_update_properties_btn (self);
#line 83 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	boxes_selectionbar_update_pause_btn (self);
#line 84 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	boxes_selectionbar_update_delete_btn (self);
#line 858 "selectionbar.c"
}


static void ___lambda179__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 80 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	__lambda179_ (self);
#line 865 "selectionbar.c"
}


BoxesSelectionbar* boxes_selectionbar_construct (GType object_type) {
	BoxesSelectionbar * self = NULL;
	GtkHeaderBar* _tmp0_ = NULL;
	GtkHeaderBar* _tmp1_ = NULL;
	GtkStyleContext* _tmp2_ = NULL;
	GtkHeaderBar* _tmp3_ = NULL;
	GtkToggleButton* _tmp4_ = NULL;
	GtkHeaderBar* _tmp5_ = NULL;
	GtkToggleButton* _tmp6_ = NULL;
	GtkToggleButton* _tmp7_ = NULL;
	GtkImage* _tmp8_ = NULL;
	GtkImage* _tmp9_ = NULL;
	GtkToggleButton* _tmp10_ = NULL;
	GtkToggleButton* _tmp11_ = NULL;
	GtkStyleContext* _tmp12_ = NULL;
	GtkToggleButton* _tmp13_ = NULL;
	gulong _tmp14_ = 0UL;
	const gchar* _tmp15_ = NULL;
	GtkButton* _tmp16_ = NULL;
	GtkButton* _tmp17_ = NULL;
	GtkHeaderBar* _tmp18_ = NULL;
	GtkButton* _tmp19_ = NULL;
	GtkButton* _tmp20_ = NULL;
	GtkStyleContext* _tmp21_ = NULL;
	GtkButton* _tmp22_ = NULL;
	const gchar* _tmp23_ = NULL;
	GtkButton* _tmp24_ = NULL;
	GtkButton* _tmp25_ = NULL;
	GtkHeaderBar* _tmp26_ = NULL;
	GtkButton* _tmp27_ = NULL;
	GtkButton* _tmp28_ = NULL;
	GtkStyleContext* _tmp29_ = NULL;
	GtkButton* _tmp30_ = NULL;
	const gchar* _tmp31_ = NULL;
	GtkButton* _tmp32_ = NULL;
	GtkButton* _tmp33_ = NULL;
	GtkHeaderBar* _tmp34_ = NULL;
	GtkButton* _tmp35_ = NULL;
	GtkButton* _tmp36_ = NULL;
	GtkStyleContext* _tmp37_ = NULL;
	GtkButton* _tmp38_ = NULL;
	BoxesApp* _tmp39_ = NULL;
	BoxesApp* _tmp40_ = NULL;
#line 13 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	self = (BoxesSelectionbar*) g_object_new (object_type, NULL);
#line 14 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	gtk_revealer_set_transition_type ((GtkRevealer*) self, GTK_REVEALER_TRANSITION_TYPE_SLIDE_UP);
#line 16 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp0_ = (GtkHeaderBar*) gtk_header_bar_new ();
#line 16 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	g_object_ref_sink (_tmp0_);
#line 16 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_g_object_unref0 (self->priv->headerbar);
#line 16 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	self->priv->headerbar = _tmp0_;
#line 17 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp1_ = self->priv->headerbar;
#line 17 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp2_ = gtk_widget_get_style_context ((GtkWidget*) _tmp1_);
#line 17 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	gtk_style_context_add_class (_tmp2_, "titlebar");
#line 18 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp3_ = self->priv->headerbar;
#line 18 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	gtk_container_add ((GtkContainer*) self, (GtkWidget*) _tmp3_);
#line 20 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp4_ = (GtkToggleButton*) gtk_toggle_button_new ();
#line 20 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	g_object_ref_sink (_tmp4_);
#line 20 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_g_object_unref0 (self->priv->favorite_btn);
#line 20 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	self->priv->favorite_btn = _tmp4_;
#line 21 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp5_ = self->priv->headerbar;
#line 21 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp6_ = self->priv->favorite_btn;
#line 21 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	gtk_header_bar_pack_start (_tmp5_, (GtkWidget*) _tmp6_);
#line 22 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp7_ = self->priv->favorite_btn;
#line 22 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp8_ = (GtkImage*) gtk_image_new_from_icon_name ("emblem-favorite-symbolic", GTK_ICON_SIZE_MENU);
#line 22 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	g_object_ref_sink (_tmp8_);
#line 22 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp9_ = _tmp8_;
#line 22 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	gtk_button_set_image ((GtkButton*) _tmp7_, (GtkWidget*) _tmp9_);
#line 22 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_g_object_unref0 (_tmp9_);
#line 23 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp10_ = self->priv->favorite_btn;
#line 23 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	gtk_widget_set_valign ((GtkWidget*) _tmp10_, GTK_ALIGN_CENTER);
#line 24 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp11_ = self->priv->favorite_btn;
#line 24 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp12_ = gtk_widget_get_style_context ((GtkWidget*) _tmp11_);
#line 24 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	gtk_style_context_add_class (_tmp12_, "image-button");
#line 25 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp13_ = self->priv->favorite_btn;
#line 25 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp14_ = g_signal_connect_object ((GtkButton*) _tmp13_, "clicked", (GCallback) ___lambda171__gtk_button_clicked, self, 0);
#line 25 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	self->priv->favorite_btn_clicked_handler = _tmp14_;
#line 36 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp15_ = _ ("P_ause");
#line 36 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp16_ = (GtkButton*) gtk_button_new_with_mnemonic (_tmp15_);
#line 36 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	g_object_ref_sink (_tmp16_);
#line 36 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_g_object_unref0 (self->priv->pause_btn);
#line 36 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	self->priv->pause_btn = _tmp16_;
#line 37 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp17_ = self->priv->pause_btn;
#line 37 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	gtk_widget_set_valign ((GtkWidget*) _tmp17_, GTK_ALIGN_CENTER);
#line 38 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp18_ = self->priv->headerbar;
#line 38 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp19_ = self->priv->pause_btn;
#line 38 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	gtk_header_bar_pack_start (_tmp18_, (GtkWidget*) _tmp19_);
#line 39 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp20_ = self->priv->pause_btn;
#line 39 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp21_ = gtk_widget_get_style_context ((GtkWidget*) _tmp20_);
#line 39 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	gtk_style_context_add_class (_tmp21_, "text-button");
#line 40 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp22_ = self->priv->pause_btn;
#line 40 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	g_signal_connect_object (_tmp22_, "clicked", (GCallback) ___lambda172__gtk_button_clicked, self, 0);
#line 58 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp23_ = _ ("_Delete");
#line 58 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp24_ = (GtkButton*) gtk_button_new_with_mnemonic (_tmp23_);
#line 58 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	g_object_ref_sink (_tmp24_);
#line 58 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_g_object_unref0 (self->priv->remove_btn);
#line 58 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	self->priv->remove_btn = _tmp24_;
#line 59 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp25_ = self->priv->remove_btn;
#line 59 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	gtk_widget_set_valign ((GtkWidget*) _tmp25_, GTK_ALIGN_CENTER);
#line 60 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp26_ = self->priv->headerbar;
#line 60 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp27_ = self->priv->remove_btn;
#line 60 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	gtk_header_bar_pack_start (_tmp26_, (GtkWidget*) _tmp27_);
#line 61 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp28_ = self->priv->remove_btn;
#line 61 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp29_ = gtk_widget_get_style_context ((GtkWidget*) _tmp28_);
#line 61 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	gtk_style_context_add_class (_tmp29_, "text-button");
#line 62 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp30_ = self->priv->remove_btn;
#line 62 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	g_signal_connect_object (_tmp30_, "clicked", (GCallback) ___lambda174__gtk_button_clicked, self, 0);
#line 66 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp31_ = _ ("_Properties");
#line 66 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp32_ = (GtkButton*) gtk_button_new_with_mnemonic (_tmp31_);
#line 66 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	g_object_ref_sink (_tmp32_);
#line 66 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_g_object_unref0 (self->priv->properties_btn);
#line 66 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	self->priv->properties_btn = _tmp32_;
#line 67 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp33_ = self->priv->properties_btn;
#line 67 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	gtk_widget_set_valign ((GtkWidget*) _tmp33_, GTK_ALIGN_CENTER);
#line 68 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp34_ = self->priv->headerbar;
#line 68 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp35_ = self->priv->properties_btn;
#line 68 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	gtk_header_bar_pack_end (_tmp34_, (GtkWidget*) _tmp35_);
#line 69 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp36_ = self->priv->properties_btn;
#line 69 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp37_ = gtk_widget_get_style_context ((GtkWidget*) _tmp36_);
#line 69 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	gtk_style_context_add_class (_tmp37_, "text-button");
#line 70 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp38_ = self->priv->properties_btn;
#line 70 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	g_signal_connect_object (_tmp38_, "clicked", (GCallback) ___lambda177__gtk_button_clicked, self, 0);
#line 74 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	gtk_widget_show_all ((GtkWidget*) self);
#line 76 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp39_ = boxes_app_app;
#line 76 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	g_signal_connect_object ((GObject*) _tmp39_, "notify::selection-mode", (GCallback) ___lambda178__g_object_notify, self, 0);
#line 80 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp40_ = boxes_app_app;
#line 80 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	g_signal_connect_object ((GObject*) _tmp40_, "notify::selected-items", (GCallback) ___lambda179__g_object_notify, self, 0);
#line 13 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	return self;
#line 1078 "selectionbar.c"
}


BoxesSelectionbar* boxes_selectionbar_new (void) {
#line 13 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	return boxes_selectionbar_construct (BOXES_TYPE_SELECTIONBAR);
#line 1085 "selectionbar.c"
}


static gboolean _vala_string_array_contains (gchar** stack, int stack_length, gchar* needle) {
	int i;
#line 97 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	for (i = 0; i < stack_length; i++) {
#line 97 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
		if (g_strcmp0 (stack[i], needle) == 0) {
#line 97 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
			return TRUE;
#line 1097 "selectionbar.c"
		}
	}
#line 97 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	return FALSE;
#line 1102 "selectionbar.c"
}


static void boxes_selectionbar_update_favorite_btn (BoxesSelectionbar* self) {
	gboolean active = FALSE;
	gboolean sensitive = FALSE;
	BoxesApp* _tmp0_ = NULL;
	GList* _tmp1_ = NULL;
	GList* _tmp2_ = NULL;
	GList* _tmp3_ = NULL;
	guint _tmp4_ = 0U;
	gboolean _tmp5_ = FALSE;
	BoxesApp* _tmp6_ = NULL;
	GList* _tmp7_ = NULL;
	GList* _tmp8_ = NULL;
	GtkToggleButton* _tmp22_ = NULL;
	gulong _tmp23_ = 0UL;
	GtkToggleButton* _tmp24_ = NULL;
	gboolean _tmp25_ = FALSE;
	GtkToggleButton* _tmp26_ = NULL;
	gboolean _tmp27_ = FALSE;
	GtkToggleButton* _tmp28_ = NULL;
	gulong _tmp29_ = 0UL;
#line 88 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	g_return_if_fail (self != NULL);
#line 89 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	active = FALSE;
#line 90 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp0_ = boxes_app_app;
#line 90 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp1_ = boxes_app_get_selected_items (_tmp0_);
#line 90 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp2_ = _tmp1_;
#line 90 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp3_ = _tmp2_;
#line 90 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp4_ = g_list_length (_tmp3_);
#line 90 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp5_ = _tmp4_ > ((guint) 0);
#line 90 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	__g_list_free__g_object_unref0_0 (_tmp3_);
#line 90 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	sensitive = _tmp5_;
#line 92 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp6_ = boxes_app_app;
#line 92 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp7_ = boxes_app_get_selected_items (_tmp6_);
#line 92 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp8_ = _tmp7_;
#line 1152 "selectionbar.c"
	{
		GList* item_collection = NULL;
		GList* item_it = NULL;
#line 92 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
		item_collection = _tmp8_;
#line 92 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
		for (item_it = item_collection; item_it != NULL; item_it = item_it->next) {
#line 1160 "selectionbar.c"
			BoxesCollectionItem* _tmp9_ = NULL;
			BoxesCollectionItem* item = NULL;
#line 92 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
			_tmp9_ = _g_object_ref0 ((BoxesCollectionItem*) item_it->data);
#line 92 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
			item = _tmp9_;
#line 1167 "selectionbar.c"
			{
				BoxesMachine* machine = NULL;
				BoxesCollectionItem* _tmp10_ = NULL;
				BoxesMachine* _tmp11_ = NULL;
				BoxesMachine* _tmp12_ = NULL;
				gboolean is_favorite = FALSE;
				BoxesMachine* _tmp13_ = NULL;
				BoxesBoxConfig* _tmp14_ = NULL;
				gchar** _tmp15_ = NULL;
				gint _tmp15__length1 = 0;
				gchar** _tmp16_ = NULL;
				gint _tmp16__length1 = 0;
				gchar** _tmp17_ = NULL;
				gint _tmp17__length1 = 0;
				gboolean _tmp18_ = FALSE;
				gboolean _tmp19_ = FALSE;
#line 93 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				_tmp10_ = item;
#line 93 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				_tmp11_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp10_, BOXES_TYPE_MACHINE) ? ((BoxesMachine*) _tmp10_) : NULL);
#line 93 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				machine = _tmp11_;
#line 94 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				_tmp12_ = machine;
#line 94 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				if (_tmp12_ == NULL) {
#line 95 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
					_g_object_unref0 (machine);
#line 95 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
					_g_object_unref0 (item);
#line 95 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
					continue;
#line 1200 "selectionbar.c"
				}
#line 97 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				_tmp13_ = machine;
#line 97 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				_tmp14_ = _tmp13_->config;
#line 97 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				_tmp15_ = boxes_box_config_get_categories (_tmp14_, &_tmp15__length1);
#line 97 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				_tmp16_ = _tmp15_;
#line 97 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				_tmp16__length1 = _tmp15__length1;
#line 97 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				_tmp17_ = _tmp16_;
#line 97 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				_tmp17__length1 = _tmp16__length1;
#line 97 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				_tmp18_ = _vala_string_array_contains (_tmp17_, _tmp16__length1, "favorite");
#line 97 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				_tmp17_ = (_vala_array_free (_tmp17_, _tmp17__length1, (GDestroyNotify) g_free), NULL);
#line 97 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				is_favorite = _tmp18_;
#line 98 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				_tmp19_ = active;
#line 98 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				if (!_tmp19_) {
#line 1226 "selectionbar.c"
					gboolean _tmp20_ = FALSE;
#line 99 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
					_tmp20_ = is_favorite;
#line 99 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
					active = _tmp20_;
#line 1232 "selectionbar.c"
				} else {
					gboolean _tmp21_ = FALSE;
#line 100 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
					_tmp21_ = is_favorite;
#line 100 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
					if (!_tmp21_) {
#line 101 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
						sensitive = FALSE;
#line 102 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
						_g_object_unref0 (machine);
#line 102 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
						_g_object_unref0 (item);
#line 102 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
						break;
#line 1247 "selectionbar.c"
					}
				}
#line 92 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				_g_object_unref0 (machine);
#line 92 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				_g_object_unref0 (item);
#line 1254 "selectionbar.c"
			}
		}
#line 92 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
		__g_list_free__g_object_unref0_0 (item_collection);
#line 1259 "selectionbar.c"
	}
#line 108 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp22_ = self->priv->favorite_btn;
#line 108 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp23_ = self->priv->favorite_btn_clicked_handler;
#line 108 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	g_signal_handler_block (_tmp22_, _tmp23_);
#line 109 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp24_ = self->priv->favorite_btn;
#line 109 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp25_ = active;
#line 109 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	gtk_toggle_button_set_active (_tmp24_, _tmp25_);
#line 110 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp26_ = self->priv->favorite_btn;
#line 110 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp27_ = sensitive;
#line 110 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	gtk_widget_set_sensitive ((GtkWidget*) _tmp26_, _tmp27_);
#line 111 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp28_ = self->priv->favorite_btn;
#line 111 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp29_ = self->priv->favorite_btn_clicked_handler;
#line 111 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	g_signal_handler_unblock (_tmp28_, _tmp29_);
#line 1285 "selectionbar.c"
}


static void boxes_selectionbar_update_properties_btn (BoxesSelectionbar* self) {
	gboolean sensitive = FALSE;
	BoxesApp* _tmp0_ = NULL;
	GList* _tmp1_ = NULL;
	GList* _tmp2_ = NULL;
	GList* _tmp3_ = NULL;
	guint _tmp4_ = 0U;
	gboolean _tmp5_ = FALSE;
	GtkButton* _tmp6_ = NULL;
#line 114 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	g_return_if_fail (self != NULL);
#line 115 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp0_ = boxes_app_app;
#line 115 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp1_ = boxes_app_get_selected_items (_tmp0_);
#line 115 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp2_ = _tmp1_;
#line 115 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp3_ = _tmp2_;
#line 115 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp4_ = g_list_length (_tmp3_);
#line 115 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp5_ = _tmp4_ == ((guint) 1);
#line 115 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	__g_list_free__g_object_unref0_0 (_tmp3_);
#line 115 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	sensitive = _tmp5_;
#line 117 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp6_ = self->priv->properties_btn;
#line 117 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	gtk_widget_set_sensitive ((GtkWidget*) _tmp6_, sensitive);
#line 1320 "selectionbar.c"
}


static void boxes_selectionbar_update_pause_btn (BoxesSelectionbar* self) {
	gboolean sensitive = FALSE;
	BoxesApp* _tmp0_ = NULL;
	GList* _tmp1_ = NULL;
	GList* _tmp2_ = NULL;
	GtkButton* _tmp15_ = NULL;
	gboolean _tmp16_ = FALSE;
#line 120 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	g_return_if_fail (self != NULL);
#line 121 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	sensitive = FALSE;
#line 122 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp0_ = boxes_app_app;
#line 122 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp1_ = boxes_app_get_selected_items (_tmp0_);
#line 122 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp2_ = _tmp1_;
#line 1341 "selectionbar.c"
	{
		GList* item_collection = NULL;
		GList* item_it = NULL;
#line 122 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
		item_collection = _tmp2_;
#line 122 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
		for (item_it = item_collection; item_it != NULL; item_it = item_it->next) {
#line 1349 "selectionbar.c"
			BoxesCollectionItem* _tmp3_ = NULL;
			BoxesCollectionItem* item = NULL;
#line 122 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
			_tmp3_ = _g_object_ref0 ((BoxesCollectionItem*) item_it->data);
#line 122 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
			item = _tmp3_;
#line 1356 "selectionbar.c"
			{
				BoxesCollectionItem* _tmp4_ = NULL;
				BoxesMachine* machine = NULL;
				BoxesCollectionItem* _tmp5_ = NULL;
				BoxesMachine* _tmp6_ = NULL;
				gboolean _tmp7_ = FALSE;
				BoxesMachine* _tmp8_ = NULL;
				gboolean _tmp9_ = FALSE;
				gboolean _tmp10_ = FALSE;
				gboolean _tmp14_ = FALSE;
#line 123 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				_tmp4_ = item;
#line 123 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				if (!G_TYPE_CHECK_INSTANCE_TYPE (_tmp4_, BOXES_TYPE_MACHINE)) {
#line 124 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
					_g_object_unref0 (item);
#line 124 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
					continue;
#line 1375 "selectionbar.c"
				}
#line 126 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				_tmp5_ = item;
#line 126 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				_tmp6_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp5_, BOXES_TYPE_MACHINE) ? ((BoxesMachine*) _tmp5_) : NULL);
#line 126 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				machine = _tmp6_;
#line 127 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				_tmp8_ = machine;
#line 127 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				_tmp9_ = boxes_machine_get_can_save (_tmp8_);
#line 127 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				_tmp10_ = _tmp9_;
#line 127 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				if (_tmp10_) {
#line 1391 "selectionbar.c"
					BoxesMachine* _tmp11_ = NULL;
					BoxesMachineMachineState _tmp12_ = 0;
					BoxesMachineMachineState _tmp13_ = 0;
#line 127 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
					_tmp11_ = machine;
#line 127 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
					_tmp12_ = boxes_machine_get_state (_tmp11_);
#line 127 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
					_tmp13_ = _tmp12_;
#line 127 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
					_tmp7_ = _tmp13_ != BOXES_MACHINE_MACHINE_STATE_SAVED;
#line 1403 "selectionbar.c"
				} else {
#line 127 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
					_tmp7_ = FALSE;
#line 1407 "selectionbar.c"
				}
#line 127 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				_tmp14_ = _tmp7_;
#line 127 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				if (_tmp14_) {
#line 128 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
					sensitive = TRUE;
#line 130 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
					_g_object_unref0 (machine);
#line 130 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
					_g_object_unref0 (item);
#line 130 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
					break;
#line 1421 "selectionbar.c"
				}
#line 122 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				_g_object_unref0 (machine);
#line 122 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				_g_object_unref0 (item);
#line 1427 "selectionbar.c"
			}
		}
#line 122 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
		__g_list_free__g_object_unref0_0 (item_collection);
#line 1432 "selectionbar.c"
	}
#line 134 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp15_ = self->priv->pause_btn;
#line 134 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp16_ = sensitive;
#line 134 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	gtk_widget_set_sensitive ((GtkWidget*) _tmp15_, _tmp16_);
#line 1440 "selectionbar.c"
}


static void ____lambda180_ (BoxesSelectionbar* self) {
#line 150 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	boxes_selectionbar_update_delete_btn (self);
#line 1447 "selectionbar.c"
}


static void _____lambda180__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 149 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	____lambda180_ (self);
#line 1454 "selectionbar.c"
}


static void boxes_selectionbar_update_delete_btn (BoxesSelectionbar* self) {
	BoxesApp* _tmp0_ = NULL;
	BoxesCollection* _tmp1_ = NULL;
	GPtrArray* _tmp2_ = NULL;
	gpointer* _tmp3_ = NULL;
	gint _tmp3__length1 = 0;
	gboolean sensitive = FALSE;
	BoxesApp* _tmp11_ = NULL;
	GList* _tmp12_ = NULL;
	GList* _tmp13_ = NULL;
	GList* _tmp14_ = NULL;
	guint _tmp15_ = 0U;
	gboolean _tmp16_ = FALSE;
	BoxesApp* _tmp17_ = NULL;
	GList* _tmp18_ = NULL;
	GList* _tmp19_ = NULL;
	GtkButton* _tmp31_ = NULL;
	gboolean _tmp32_ = FALSE;
#line 137 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	g_return_if_fail (self != NULL);
#line 138 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp0_ = boxes_app_app;
#line 138 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp1_ = _tmp0_->collection;
#line 138 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp2_ = _tmp1_->items;
#line 138 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp3_ = _tmp2_->pdata;
#line 138 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp3__length1 = (gint) _tmp2_->len;
#line 1488 "selectionbar.c"
	{
		BoxesCollectionItem** item_collection = NULL;
		gint item_collection_length1 = 0;
		gint _item_collection_size_ = 0;
		gint item_it = 0;
#line 138 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
		item_collection = _tmp3_;
#line 138 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
		item_collection_length1 = _tmp3__length1;
#line 138 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
		for (item_it = 0; item_it < _tmp3__length1; item_it = item_it + 1) {
#line 1500 "selectionbar.c"
			BoxesCollectionItem* _tmp4_ = NULL;
			BoxesCollectionItem* item = NULL;
#line 138 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
			_tmp4_ = _g_object_ref0 (item_collection[item_it]);
#line 138 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
			item = _tmp4_;
#line 1507 "selectionbar.c"
			{
				gulong can_delete_id = 0UL;
				BoxesCollectionItem* _tmp5_ = NULL;
				gconstpointer _tmp6_ = NULL;
				gulong _tmp7_ = 0UL;
#line 139 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				_tmp5_ = item;
#line 139 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				_tmp6_ = g_object_get_data ((GObject*) _tmp5_, "can_delete_id");
#line 139 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				can_delete_id = (gulong) ((guintptr) _tmp6_);
#line 140 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				_tmp7_ = can_delete_id;
#line 140 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				if (_tmp7_ > ((gulong) 0)) {
#line 1523 "selectionbar.c"
					BoxesCollectionItem* _tmp8_ = NULL;
					gulong _tmp9_ = 0UL;
					BoxesCollectionItem* _tmp10_ = NULL;
#line 141 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
					_tmp8_ = item;
#line 141 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
					_tmp9_ = can_delete_id;
#line 141 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
					g_signal_handler_disconnect ((GObject*) _tmp8_, _tmp9_);
#line 142 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
					_tmp10_ = item;
#line 142 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
					g_object_set_data_full ((GObject*) _tmp10_, "can_delete_id", (gpointer) ((guintptr) ((gulong) 0)), NULL);
#line 1537 "selectionbar.c"
				}
#line 138 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				_g_object_unref0 (item);
#line 1541 "selectionbar.c"
			}
		}
	}
#line 146 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp11_ = boxes_app_app;
#line 146 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp12_ = boxes_app_get_selected_items (_tmp11_);
#line 146 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp13_ = _tmp12_;
#line 146 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp14_ = _tmp13_;
#line 146 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp15_ = g_list_length (_tmp14_);
#line 146 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp16_ = _tmp15_ > ((guint) 0);
#line 146 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	__g_list_free__g_object_unref0_0 (_tmp14_);
#line 146 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	sensitive = _tmp16_;
#line 147 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp17_ = boxes_app_app;
#line 147 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp18_ = boxes_app_get_selected_items (_tmp17_);
#line 147 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp19_ = _tmp18_;
#line 1567 "selectionbar.c"
	{
		GList* item_collection = NULL;
		GList* item_it = NULL;
#line 147 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
		item_collection = _tmp19_;
#line 147 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
		for (item_it = item_collection; item_it != NULL; item_it = item_it->next) {
#line 1575 "selectionbar.c"
			BoxesCollectionItem* _tmp20_ = NULL;
			BoxesCollectionItem* item = NULL;
#line 147 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
			_tmp20_ = _g_object_ref0 ((BoxesCollectionItem*) item_it->data);
#line 147 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
			item = _tmp20_;
#line 1582 "selectionbar.c"
			{
				gulong can_delete_id = 0UL;
				BoxesCollectionItem* _tmp21_ = NULL;
				gulong _tmp22_ = 0UL;
				BoxesCollectionItem* _tmp23_ = NULL;
				gulong _tmp24_ = 0UL;
				gboolean _tmp25_ = FALSE;
				BoxesCollectionItem* _tmp26_ = NULL;
				gboolean _tmp30_ = FALSE;
#line 148 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				can_delete_id = (gulong) 0;
#line 149 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				_tmp21_ = item;
#line 149 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				_tmp22_ = g_signal_connect_object ((GObject*) _tmp21_, "notify::can-delete", (GCallback) _____lambda180__g_object_notify, self, 0);
#line 149 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				can_delete_id = _tmp22_;
#line 152 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				_tmp23_ = item;
#line 152 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				_tmp24_ = can_delete_id;
#line 152 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				g_object_set_data_full ((GObject*) _tmp23_, "can_delete_id", (gpointer) ((guintptr) _tmp24_), NULL);
#line 154 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				_tmp26_ = item;
#line 154 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp26_, BOXES_TYPE_MACHINE)) {
#line 1610 "selectionbar.c"
					BoxesCollectionItem* _tmp27_ = NULL;
					gboolean _tmp28_ = FALSE;
					gboolean _tmp29_ = FALSE;
#line 154 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
					_tmp27_ = item;
#line 154 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
					_tmp28_ = boxes_machine_get_can_delete (G_TYPE_CHECK_INSTANCE_TYPE (_tmp27_, BOXES_TYPE_MACHINE) ? ((BoxesMachine*) _tmp27_) : NULL);
#line 154 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
					_tmp29_ = _tmp28_;
#line 154 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
					_tmp25_ = !_tmp29_;
#line 1622 "selectionbar.c"
				} else {
#line 154 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
					_tmp25_ = FALSE;
#line 1626 "selectionbar.c"
				}
#line 154 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				_tmp30_ = _tmp25_;
#line 154 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				if (_tmp30_) {
#line 155 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
					sensitive = FALSE;
#line 156 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
					_g_object_unref0 (item);
#line 156 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
					break;
#line 1638 "selectionbar.c"
				}
#line 147 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
				_g_object_unref0 (item);
#line 1642 "selectionbar.c"
			}
		}
#line 147 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
		__g_list_free__g_object_unref0_0 (item_collection);
#line 1647 "selectionbar.c"
	}
#line 160 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp31_ = self->priv->remove_btn;
#line 160 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_tmp32_ = sensitive;
#line 160 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	gtk_widget_set_sensitive ((GtkWidget*) _tmp31_, _tmp32_);
#line 1655 "selectionbar.c"
}


static void boxes_selectionbar_class_init (BoxesSelectionbarClass * klass) {
#line 5 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	boxes_selectionbar_parent_class = g_type_class_peek_parent (klass);
#line 5 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	g_type_class_add_private (klass, sizeof (BoxesSelectionbarPrivate));
#line 5 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	G_OBJECT_CLASS (klass)->finalize = boxes_selectionbar_finalize;
#line 1666 "selectionbar.c"
}


static void boxes_selectionbar_instance_init (BoxesSelectionbar * self) {
#line 5 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	self->priv = BOXES_SELECTIONBAR_GET_PRIVATE (self);
#line 1673 "selectionbar.c"
}


static void boxes_selectionbar_finalize (GObject* obj) {
	BoxesSelectionbar * self;
#line 5 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_SELECTIONBAR, BoxesSelectionbar);
#line 6 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_g_object_unref0 (self->priv->headerbar);
#line 7 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_g_object_unref0 (self->priv->favorite_btn);
#line 8 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_g_object_unref0 (self->priv->pause_btn);
#line 9 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_g_object_unref0 (self->priv->remove_btn);
#line 10 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	_g_object_unref0 (self->priv->properties_btn);
#line 5 "/extra-data/checkout/gnome/gnome-boxes/src/selectionbar.vala"
	G_OBJECT_CLASS (boxes_selectionbar_parent_class)->finalize (obj);
#line 1693 "selectionbar.c"
}


GType boxes_selectionbar_get_type (void) {
	static volatile gsize boxes_selectionbar_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_selectionbar_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (BoxesSelectionbarClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) boxes_selectionbar_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (BoxesSelectionbar), 0, (GInstanceInitFunc) boxes_selectionbar_instance_init, NULL };
		GType boxes_selectionbar_type_id;
		boxes_selectionbar_type_id = g_type_register_static (GTK_TYPE_REVEALER, "BoxesSelectionbar", &g_define_type_info, 0);
		g_once_init_leave (&boxes_selectionbar_type_id__volatile, boxes_selectionbar_type_id);
	}
	return boxes_selectionbar_type_id__volatile;
}


static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func) {
#line 471 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if ((array != NULL) && (destroy_func != NULL)) {
#line 1712 "selectionbar.c"
		int i;
#line 471 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		for (i = 0; i < array_length; i = i + 1) {
#line 471 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			if (((gpointer*) array)[i] != NULL) {
#line 471 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				destroy_func (((gpointer*) array)[i]);
#line 1720 "selectionbar.c"
			}
		}
	}
}


static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func) {
#line 471 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_vala_array_destroy (array, array_length, destroy_func);
#line 471 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_free (array);
#line 1732 "selectionbar.c"
}



